@@ -27,22 +27,26 @@ db_share.connect()
 def get_industries_val(start_day = '2001-01-01', end_day = '2050-01-01', db = db_share):
     val_industries = pd.read_sql("""SELECT * FROM "中信行业指数每日估值" WHERE
                                    "日期" >= '{}' AND "日期" <= '{}' """.format(start_day, end_day), con=db)
+    val_industries['日期'] = pd.to_datetime(val_industries['日期'])
     return val_industries
 
 def get_industries_return(start_day = '2001-01-01', end_day = '2050-01-01', db = db_share):
     ret_industries  = pd.read_sql("""SELECT * FROM "中信行业指数日收益率" WHERE
                                    "日期" >= '{}' AND "日期" <= '{}' """.format(start_day, end_day), con=db)
+    ret_industries['日期'] = pd.to_datetime(ret_industries['日期'])
     return ret_industries
 
 def get_industries_estimate(start_day = '2001-01-01', end_day = '2050-01-01', db = db_share):
     est_industries = pd.read_sql("""SELECT * FROM "中信行业指数一致预期" WHERE
                                    "日期" >= '{}' AND "日期" <= '{}' """.format(start_day, end_day), con = db)
+    est_industries['日期'] = pd.to_datetime(est_industries['日期'])
     return est_industries
 
 def get_industries_roe(start_day = '2001-01-01', end_day = '2050-01-01', db = db_share):
-    fa_industries = pd.read_sql("""SELECT * FROM "中信行业加权ROE" WHERE
+    roe_industries = pd.read_sql("""SELECT * FROM "中信行业加权ROE" WHERE
                                    "报告期" >= '{}' AND "报告期" <= '{}' """.format(start_day, end_day), con=db)
-    return fa_industries    
+    roe_industries['报告期'] = pd.to_datetime(roe_industries['报告期'])
+    return roe_industries    
 
 
 
